@@ -4,11 +4,12 @@
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
 // This program is written by Stefan Prestel.
-// It illustrates how to do UMEPS merging, 
-// see the Matrix Element Merging page in the online manual. 
+// It illustrates how to do UMEPS merging,
+// see the Matrix Element Merging page in the online manual.
 
 #include "Pythia8/Pythia.h"
 #include "Pythia8/Pythia8ToHepMC.h"
+#include <unistd.h>
 
 #include "HepMC/GenEvent.h"
 #include "HepMC/IO_GenEvent.h"
@@ -39,7 +40,7 @@ int main( int argc, char* argv[] ){
 
   // Input parameters:
   pythia.readFile(argv[1]);
-  // Interface for conversion from Pythia8::Event to HepMC one. 
+  // Interface for conversion from Pythia8::Event to HepMC one.
   HepMC::Pythia8ToHepMC ToHepMC;
   // Specify file where HepMC events will be stored.
   HepMC::IO_GenEvent ascii_io(argv[3], std::ios::out);
@@ -99,7 +100,7 @@ int main( int argc, char* argv[] ){
 
     LHAupLHEF lhareader((char*)(LHEfile).c_str());
     pythia.settings.mode("Merging:nRequested", njetcounterLO);
-    pythia.settings.word("Beams:LHEF", LHEfile);  
+    pythia.settings.word("Beams:LHEF", LHEfile);
     pythia.init(&lhareader);
 
     // Start generation loop
@@ -110,7 +111,7 @@ int main( int argc, char* argv[] ){
           break;
         }
         else continue;
-      } 
+      }
     } // end loop over events to generate
 
     // print cross section, errors
@@ -169,7 +170,7 @@ int main( int argc, char* argv[] ){
          << endl;
 
     pythia.settings.mode("Merging:nRequested", njetcounterLO);
-    pythia.settings.word("Beams:LHEF", LHEfile); 
+    pythia.settings.word("Beams:LHEF", LHEfile);
     pythia.init(&lhareader);
 
     // Remember position in vector of cross section estimates.
@@ -189,7 +190,7 @@ int main( int argc, char* argv[] ){
       double evtweight = pythia.info.weight();
       weight *= evtweight;
       // Do not print zero-weight events.
-      if ( weight == 0. ) continue; 
+      if ( weight == 0. ) continue;
       
       // Construct new empty HepMC event.
       HepMC::GenEvent* hepmcevt = new HepMC::GenEvent();
@@ -273,7 +274,7 @@ int main( int argc, char* argv[] ){
       double evtweight = pythia.info.weight();
       weight *= evtweight;
       // Do not print zero-weight events.
-      if ( weight == 0. ) continue; 
+      if ( weight == 0. ) continue;
 
       // Construct new empty HepMC event.
       HepMC::GenEvent* hepmcevt = new HepMC::GenEvent();
