@@ -26,70 +26,70 @@ echo "<font color='red'>NO FILE SELECTED YET.. PLEASE DO SO </font><a href='Save
 ?>
 
 <form method='post' action='TopProcesses.php'>
-
-<h2>Top Processes</h2>
-
-Different ways to produce top quarks, singly or in pairs.
-
+ 
+<h2>Top Processes</h2> 
+ 
+Different ways to produce top quarks, singly or in pairs. 
+ 
 <br/><br/><strong>Top:all</strong>  <input type="radio" name="1" value="on"><strong>On</strong>
 <input type="radio" name="1" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Common switch for the group of top production.
-  
-
+Common switch for the group of top production. 
+   
+ 
 <br/><br/><strong>Top:gg2ttbar</strong>  <input type="radio" name="2" value="on"><strong>On</strong>
 <input type="radio" name="2" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Scatterings <i>g g -> t tbar</i>. 
-Code 601.
-  
-
+Scatterings <i>g g &rarr; t tbar</i>. 
+Code 601. 
+   
+ 
 <br/><br/><strong>Top:qqbar2ttbar</strong>  <input type="radio" name="3" value="on"><strong>On</strong>
 <input type="radio" name="3" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Scatterings <i>q qbar -> t tbar</i> by gluon exchange. 
-Code 602.
-  
-
+Scatterings <i>q qbar &rarr; t tbar</i> by gluon exchange. 
+Code 602. 
+   
+ 
 <br/><br/><strong>Top:qq2tq(t:W)</strong>  <input type="radio" name="4" value="on"><strong>On</strong>
 <input type="radio" name="4" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Scatterings <i>q q' -> t q''</i> by <i>t</i>-channel exchange 
+Scatterings <i>q q' &rarr; t q''</i> by <i>t</i>-channel exchange 
 of a <i>W^+-</i> boson. 
-Code 603.
-  
-
+Code 603. 
+   
+ 
 <br/><br/><strong>Top:ffbar2ttbar(s:gmZ)</strong>  <input type="radio" name="5" value="on"><strong>On</strong>
 <input type="radio" name="5" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Scatterings <i>f fbar -> t tbar</i> by <i>s</i>-channel exchange 
+Scatterings <i>f fbar &rarr; t tbar</i> by <i>s</i>-channel exchange 
 of a <i>gamma^*/Z^0</i> boson. 
-Code 604.
-  
-
+Code 604. 
+   
+ 
 <br/><br/><strong>Top:ffbar2tqbar(s:W)</strong>  <input type="radio" name="6" value="on"><strong>On</strong>
 <input type="radio" name="6" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Scatterings <i>f fbar' -> t q''</i> by <i>s</i>-channel exchange 
+Scatterings <i>f fbar' &rarr; t q''</i> by <i>s</i>-channel exchange 
 of a <i>W^+-</i> boson. 
-Code 605.
-  
-
+Code 605. 
+   
+ 
 <br/><br/><strong>Top:gmgm2ttbar</strong>  <input type="radio" name="7" value="on"><strong>On</strong>
 <input type="radio" name="7" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Scatterings <i>gamma gamma -> t tbar</i>. 
-Code 606.
-  
-
-<p/>
-By default top always decays to a <i>W</i> and a down-type quark.
-It is possible to switch on the <i>t -> H+ b</i> decay mode. 
-Note that its partial width is calculated using the <i>tan(beta)</i>  
-value stored in <code>HiggsHchg:tanBeta</code>, so that it can be used
-without having to read in a SUSY parameter file. For the <i>H+</i> to
-decay also <code>Higgs:useBSM = on</code> is necessary.  
-
+Scatterings <i>gamma gamma &rarr; t tbar</i>. 
+Code 606. 
+   
+ 
+<p/> 
+By default top always decays to a <i>W</i> and a down-type quark. 
+It is possible to switch on the <i>t &rarr; H+ b</i> decay mode. 
+Note that its partial width is calculated using the <i>tan(beta)</i> 
+value stored in <code>HiggsHchg:tanBeta</code>, so that it can be used 
+without having to read in a SUSY parameter file. For the <i>H+</i> to 
+decay also <code>Higgs:useBSM = on</code> is necessary. 
+ 
 <input type="hidden" name="saved" value="1"/>
 
 <?php
@@ -146,6 +146,6 @@ fclose($handle);
 ?>
 </body>
 </html>
-
-<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
-
+ 
+<!-- Copyright (C) 2014 Torbjorn Sjostrand --> 
+ 
