@@ -1,9 +1,9 @@
 // Basics.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2013 Torbjorn Sjostrand.
+// Copyright (C) 2014 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
-// Function definitions (not found in the header) for the Rndm, Vec4, 
+// Function definitions (not found in the header) for the Rndm, Vec4,
 // RotBstMatrix and Hist classes, and some related global functions.
 
 #include "Pythia8/Basics.h"
@@ -34,7 +34,7 @@ const int Rndm::DEFAULTSEED     = 19780503;
 bool Rndm::rndmEnginePtr( RndmEngine* rndmEngPtrIn) {
 
   // Save pointer.
-  if (rndmEngPtrIn == 0) return false; 
+  if (rndmEngPtrIn == 0) return false;
   rndmEngPtr      = rndmEngPtrIn;
   useExternalRndm = true;
 
@@ -102,10 +102,10 @@ void Rndm::init(int seedIn) {
 double Rndm::flat() {
 
   // Use external random number generator if such has been linked.
-  if (useExternalRndm) return rndmEngPtr->flat();   
+  if (useExternalRndm) return rndmEngPtr->flat();
 
   // Ensure that already initialized.
-  if (!initRndm) init(DEFAULTSEED); 
+  if (!initRndm) init(DEFAULTSEED);
 
   // Find next random number and update saved state.
   ++sequence;
@@ -133,11 +133,11 @@ int Rndm::pick(const vector<double>& prob) {
 
   double work = 0.;
   for (int i = 0; i < int(prob.size()); ++i) work += prob[i];
-  work *= flat();  
+  work *= flat();
   int index = -1;
-  do work -= prob[++index]; 
+  do work -= prob[++index];
   while (work > 0. && index < int(prob.size()));
-  return index; 
+  return index;
 
 }
 
@@ -166,8 +166,8 @@ bool Rndm::dumpState(string fileName) {
   ofs.write((char *) &cm,       sizeof(double));
   ofs.write((char *) &u,        sizeof(double) * 97);
  
-  // Write confirmation on cout. 
-  cout << " PYTHIA Rndm::dumpState: seed = " << seedSave 
+  // Write confirmation on cout.
+  cout << " PYTHIA Rndm::dumpState: seed = " << seedSave
        << ", sequence no = " << sequence << endl;
   return true;
 
@@ -198,8 +198,8 @@ bool Rndm::readState(string fileName) {
   ifs.read((char *) &cm,       sizeof(double));
   ifs.read((char *) &u,        sizeof(double) *97);
 
-  // Write confirmation on cout. 
-  cout << " PYTHIA Rndm::readState: seed " << seedSave 
+  // Write confirmation on cout.
+  cout << " PYTHIA Rndm::readState: seed " << seedSave
        << ", sequence no = " << sequence << endl;
   return true;
 
@@ -225,15 +225,15 @@ const double Vec4::TINY = 1e-20;
 
 void Vec4::rot(double thetaIn, double phiIn) {
 
-  double cthe = cos(thetaIn); 
+  double cthe = cos(thetaIn);
   double sthe = sin(thetaIn);
-  double cphi = cos(phiIn); 
+  double cphi = cos(phiIn);
   double sphi = sin(phiIn);
   double tmpx =  cthe * cphi * xx -    sphi * yy + sthe * cphi * zz;
   double tmpy =  cthe * sphi * xx +    cphi * yy + sthe * sphi * zz;
-  double tmpz = -sthe *        xx +                cthe *        zz; 
-  xx          = tmpx; 
-  yy          = tmpy; 
+  double tmpz = -sthe *        xx +                cthe *        zz;
+  xx          = tmpx;
+  yy          = tmpy;
   zz          = tmpz;
 
 }
@@ -245,17 +245,17 @@ void Vec4::rot(double thetaIn, double phiIn) {
 void Vec4::rotaxis(double phiIn, double nx, double ny, double nz) {
 
   double norm = 1./sqrt(nx*nx + ny*ny + nz*nz);
-  nx         *= norm; 
-  ny         *= norm; 
-  nz         *= norm; 
-  double cphi = cos(phiIn);  
+  nx         *= norm;
+  ny         *= norm;
+  nz         *= norm;
+  double cphi = cos(phiIn);
   double sphi = sin(phiIn);
   double comb = (nx * xx + ny * yy + nz * zz) * (1. - cphi);
   double tmpx = cphi * xx + comb * nx + sphi * (ny * zz - nz * yy);
   double tmpy = cphi * yy + comb * ny + sphi * (nz * xx - nx * zz);
   double tmpz = cphi * zz + comb * nz + sphi * (nx * yy - ny * xx);
-  xx          = tmpx; 
-  yy          = tmpy; 
+  xx          = tmpx;
+  yy          = tmpy;
   zz          = tmpz;
 
 }
@@ -266,21 +266,21 @@ void Vec4::rotaxis(double phiIn, double nx, double ny, double nz) {
 
 void Vec4::rotaxis(double phiIn, const Vec4& n) {
 
-  double nx   = n.xx; 
-  double ny   = n.yy; 
+  double nx   = n.xx;
+  double ny   = n.yy;
   double nz   = n.zz;
   double norm = 1./sqrt(nx*nx + ny*ny + nz*nz);
-  nx         *= norm; 
-  ny          *=norm; 
-  nz          *=norm; 
-  double cphi = cos(phiIn);  
+  nx         *= norm;
+  ny          *=norm;
+  nz          *=norm;
+  double cphi = cos(phiIn);
   double sphi = sin(phiIn);
   double comb = (nx * xx + ny * yy + nz * zz) * (1. - cphi);
   double tmpx = cphi * xx + comb * nx + sphi * (ny * zz - nz * yy);
   double tmpy = cphi * yy + comb * ny + sphi * (nz * xx - nx * zz);
   double tmpz = cphi * zz + comb * nz + sphi * (nx * yy - ny * xx);
-  xx          = tmpx; 
-  yy          = tmpy; 
+  xx          = tmpx;
+  yy          = tmpy;
   zz          = tmpz;
 
 }
@@ -401,13 +401,13 @@ void Vec4::bstback(const Vec4& pIn, double mIn) {
 
 void Vec4::rotbst(const RotBstMatrix& M) {
 
-  double x = xx; double y = yy; double z = zz; double t = tt; 
+  double x = xx; double y = yy; double z = zz; double t = tt;
   tt = M.M[0][0] * t + M.M[0][1] * x + M.M[0][2] * y +  M.M[0][3] * z;
   xx = M.M[1][0] * t + M.M[1][1] * x + M.M[1][2] * y +  M.M[1][3] * z;
   yy = M.M[2][0] * t + M.M[2][1] * x + M.M[2][2] * y +  M.M[2][3] * z;
   zz = M.M[3][0] * t + M.M[3][1] * x + M.M[3][2] * y +  M.M[3][3] * z;
 
-} 
+}
 
 //--------------------------------------------------------------------------
 
@@ -416,7 +416,7 @@ void Vec4::rotbst(const RotBstMatrix& M) {
 double m(const Vec4& v1, const Vec4& v2) {
   double m2 = pow2(v1.tt + v2.tt) - pow2(v1.xx + v2.xx)
      - pow2(v1.yy + v2.yy) - pow2(v1.zz + v2.zz);
-  return (m2 > 0.) ? sqrt(m2) : 0.; 
+  return (m2 > 0.) ? sqrt(m2) : 0.;
 }
 
 //--------------------------------------------------------------------------
@@ -426,7 +426,7 @@ double m(const Vec4& v1, const Vec4& v2) {
 double m2(const Vec4& v1, const Vec4& v2) {
   double m2 = pow2(v1.tt + v2.tt) - pow2(v1.xx + v2.xx)
      - pow2(v1.yy + v2.yy) - pow2(v1.zz + v2.zz);
-  return m2; 
+  return m2;
 }
 
 //--------------------------------------------------------------------------
@@ -435,17 +435,17 @@ double m2(const Vec4& v1, const Vec4& v2) {
 
 double dot3(const Vec4& v1, const Vec4& v2) {
   return v1.xx*v2.xx + v1.yy*v2.yy + v1.zz*v2.zz;
-} 
+}
 
 //--------------------------------------------------------------------------
 
 // The cross product of two three-vectors.
 
-Vec4 cross3(const Vec4& v1, const Vec4& v2) { 
-  Vec4 v; 
+Vec4 cross3(const Vec4& v1, const Vec4& v2) {
+  Vec4 v;
   v.xx = v1.yy * v2.zz - v1.zz * v2.yy;
   v.yy = v1.zz * v2.xx - v1.xx * v2.zz;
-  v.zz = v1.xx * v2.yy - v1.yy * v2.xx; return v; 
+  v.zz = v1.xx * v2.yy - v1.yy * v2.xx; return v;
 }
 
 //--------------------------------------------------------------------------
@@ -454,11 +454,11 @@ Vec4 cross3(const Vec4& v1, const Vec4& v2) {
 
 double theta(const Vec4& v1, const Vec4& v2) {
   double cthe = (v1.xx * v2.xx + v1.yy * v2.yy + v1.zz * v2.zz)
-    / sqrt( (v1.xx*v1.xx + v1.yy*v1.yy + v1.zz*v1.zz) 
+    / sqrt( (v1.xx*v1.xx + v1.yy*v1.yy + v1.zz*v1.zz)
     * (v2.xx*v2.xx + v2.yy*v2.yy + v2.zz*v2.zz) );
   cthe = max(-1., min(1., cthe));
-  return acos(cthe); 
-} 
+  return acos(cthe);
+}
 
 //--------------------------------------------------------------------------
 
@@ -466,21 +466,21 @@ double theta(const Vec4& v1, const Vec4& v2) {
 
 double costheta(const Vec4& v1, const Vec4& v2) {
   double cthe = (v1.xx * v2.xx + v1.yy * v2.yy + v1.zz * v2.zz)
-    / sqrt( (v1.xx*v1.xx + v1.yy*v1.yy + v1.zz*v1.zz) 
+    / sqrt( (v1.xx*v1.xx + v1.yy*v1.yy + v1.zz*v1.zz)
     * (v2.xx*v2.xx + v2.yy*v2.yy + v2.zz*v2.zz) );
   cthe = max(-1., min(1., cthe));
-  return cthe; 
-} 
+  return cthe;
+}
 
 //--------------------------------------------------------------------------
 
 // Azimuthal angle between two three-vectors.
 
 double phi(const Vec4& v1, const Vec4& v2) {
-  double cphi = (v1.xx * v2.xx + v1.yy * v2.yy) / sqrt( max( Vec4::TINY, 
-    (v1.xx*v1.xx + v1.yy*v1.yy) * (v2.xx*v2.xx + v2.yy*v2.yy) ));  
+  double cphi = (v1.xx * v2.xx + v1.yy * v2.yy) / sqrt( max( Vec4::TINY,
+    (v1.xx*v1.xx + v1.yy*v1.yy) * (v2.xx*v2.xx + v2.yy*v2.yy) ));
   cphi = max(-1., min(1., cphi));
-  return acos(cphi); 
+  return acos(cphi);
 }
 
 //--------------------------------------------------------------------------
@@ -488,10 +488,10 @@ double phi(const Vec4& v1, const Vec4& v2) {
 // Cosine of the azimuthal angle between two three-vectors.
 
 double cosphi(const Vec4& v1, const Vec4& v2) {
-  double cphi = (v1.xx * v2.xx + v1.yy * v2.yy) / sqrt( max( Vec4::TINY, 
-    (v1.xx*v1.xx + v1.yy*v1.yy) * (v2.xx*v2.xx + v2.yy*v2.yy) ));  
+  double cphi = (v1.xx * v2.xx + v1.yy * v2.yy) / sqrt( max( Vec4::TINY,
+    (v1.xx*v1.xx + v1.yy*v1.yy) * (v2.xx*v2.xx + v2.yy*v2.yy) ));
   cphi = max(-1., min(1., cphi));
-  return cphi; 
+  return cphi;
 }
 
 //--------------------------------------------------------------------------
@@ -501,16 +501,16 @@ double cosphi(const Vec4& v1, const Vec4& v2) {
 double phi(const Vec4& v1, const Vec4& v2, const Vec4& n) {
   double nx = n.xx; double ny = n.yy; double nz = n.zz;
   double norm = 1. / sqrt(nx*nx + ny*ny + nz*nz);
-  nx *= norm; ny *=norm; nz *=norm; 
+  nx *= norm; ny *=norm; nz *=norm;
   double v1s = v1.xx * v1.xx + v1.yy * v1.yy + v1.zz * v1.zz;
   double v2s = v2.xx * v2.xx + v2.yy * v2.yy + v2.zz * v2.zz;
   double v1v2 = v1.xx * v2.xx + v1.yy * v2.yy + v1.zz * v2.zz;
   double v1n = v1.xx * nx + v1.yy * ny + v1.zz * nz;
   double v2n = v2.xx * nx + v2.yy * ny + v2.zz * nz;
-  double cphi = (v1v2 - v1n * v2n) / sqrt( max( Vec4::TINY, 
-    (v1s - v1n*v1n) * (v2s - v2n*v2n) ));  
+  double cphi = (v1v2 - v1n * v2n) / sqrt( max( Vec4::TINY,
+    (v1s - v1n*v1n) * (v2s - v2n*v2n) ));
   cphi = max(-1., min(1., cphi));
-  return acos(cphi); 
+  return acos(cphi);
 }
 
 //--------------------------------------------------------------------------
@@ -520,16 +520,16 @@ double phi(const Vec4& v1, const Vec4& v2, const Vec4& n) {
 double cosphi(const Vec4& v1, const Vec4& v2, const Vec4& n) {
   double nx = n.xx; double ny = n.yy; double nz = n.zz;
   double norm = 1. / sqrt(nx*nx + ny*ny + nz*nz);
-  nx *= norm; ny *=norm; nz *=norm; 
+  nx *= norm; ny *=norm; nz *=norm;
   double v1s = v1.xx * v1.xx + v1.yy * v1.yy + v1.zz * v1.zz;
   double v2s = v2.xx * v2.xx + v2.yy * v2.yy + v2.zz * v2.zz;
   double v1v2 = v1.xx * v2.xx + v1.yy * v2.yy + v1.zz * v2.zz;
   double v1n = v1.xx * nx + v1.yy * ny + v1.zz * nz;
   double v2n = v2.xx * nx + v2.yy * ny + v2.zz * nz;
-  double cphi = (v1v2 - v1n * v2n) / sqrt( max( Vec4::TINY, 
-    (v1s - v1n*v1n) * (v2s - v2n*v2n) ));  
+  double cphi = (v1v2 - v1n * v2n) / sqrt( max( Vec4::TINY,
+    (v1s - v1n*v1n) * (v2s - v2n*v2n) ));
   cphi = max(-1., min(1., cphi));
-  return cphi; 
+  return cphi;
 }
 
 //--------------------------------------------------------------------------
@@ -560,7 +560,7 @@ double REtaPhi(const Vec4& v1, const Vec4& v2) {
 
 ostream& operator<<(ostream& os, const Vec4& v) {
   os << fixed << setprecision(3) << " " << setw(9) << v.xx << " "
-     << setw(9) << v.yy << " " << setw(9) << v.zz << " " << setw(9) 
+     << setw(9) << v.yy << " " << setw(9) << v.zz << " " << setw(9)
      << v.tt << " (" << setw(9) << v.mCalc() << ")\n";
   return os;
 }
@@ -586,25 +586,25 @@ const double RotBstMatrix::TINY = 1e-20;
 void RotBstMatrix::rot(double theta, double phi) {
 
   // Set up rotation matrix.
-  double cthe = cos(theta); 
+  double cthe = cos(theta);
   double sthe = sin(theta);
-  double cphi = cos(phi); 
+  double cphi = cos(phi);
   double sphi = sin(phi);
-  double Mrot[4][4] = { 
-    {1.,           0.,         0.,          0.}, 
+  double Mrot[4][4] = {
+    {1.,           0.,         0.,          0.},
     {0.,  cthe * cphi,     - sphi, sthe * cphi},
     {0.,  cthe * sphi,       cphi, sthe * sphi},
     {0., -sthe,                0., cthe       } };
 
   // Rotate current matrix accordingly.
   double Mtmp[4][4];
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
-    Mtmp[i][j] = M[i][j];  
-  for (int i = 0; i < 4; ++i) 
-  for (int j = 0; j < 4; ++j) 
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    Mtmp[i][j] = M[i][j];
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
     M[i][j] = Mrot[i][0] * Mtmp[0][j] + Mrot[i][1] * Mtmp[1][j]
-            + Mrot[i][2] * Mtmp[2][j] + Mrot[i][3] * Mtmp[3][j]; 
+            + Mrot[i][2] * Mtmp[2][j] + Mrot[i][3] * Mtmp[3][j];
 
 }
 
@@ -627,11 +627,11 @@ void RotBstMatrix::rot(const Vec4& p) {
 
 void RotBstMatrix::bst(double betaX, double betaY, double betaZ) {
 
-  // Set up boost matrix.  
-  double gm = 1. / sqrt( max( TINY, 1. - betaX*betaX - betaY*betaY 
+  // Set up boost matrix.
+  double gm = 1. / sqrt( max( TINY, 1. - betaX*betaX - betaY*betaY
     - betaZ*betaZ ) );
   double gf = gm*gm / (1. + gm);
-  double Mbst[4][4] = { 
+  double Mbst[4][4] = {
     { gm,           gm*betaX,           gm*betaY,          gm*betaZ },
     { gm*betaX, 1. + gf*betaX*betaX, gf*betaX*betaY, gf*betaX*betaZ },
     { gm*betaY, gf*betaY*betaX, 1. + gf*betaY*betaY, gf*betaY*betaZ },
@@ -639,11 +639,11 @@ void RotBstMatrix::bst(double betaX, double betaY, double betaZ) {
 
   // Boost current matrix correspondingly.
   double Mtmp[4][4];
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
-    Mtmp[i][j] = M[i][j]; 
-  for (int i = 0; i < 4; ++i) 
-  for (int j = 0; j < 4; ++j) 
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    Mtmp[i][j] = M[i][j];
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
     M[i][j] = Mbst[i][0] * Mtmp[0][j] + Mbst[i][1] * Mtmp[1][j]
             + Mbst[i][2] * Mtmp[2][j] + Mbst[i][3] * Mtmp[3][j];
 
@@ -654,9 +654,9 @@ void RotBstMatrix::bst(double betaX, double betaY, double betaZ) {
 // Boost so that vector originally at rest obtains same velocity as p.
 
 void RotBstMatrix::bst(const Vec4& p) {
-  double betaX = p.px() / p.e();  
-  double betaY = p.py() / p.e();  
-  double betaZ = p.pz() / p.e();  
+  double betaX = p.px() / p.e();
+  double betaY = p.py() / p.e();
+  double betaZ = p.pz() / p.e();
   bst(betaX, betaY, betaZ);
 }
 
@@ -665,9 +665,9 @@ void RotBstMatrix::bst(const Vec4& p) {
 // Boost so vector originally with same velocity as p is brought to rest.
 
 void RotBstMatrix::bstback(const Vec4& p) {
-  double betaX = -p.px() / p.e();  
-  double betaY = -p.py() / p.e();  
-  double betaZ = -p.pz() / p.e();  
+  double betaX = -p.px() / p.e();
+  double betaY = -p.py() / p.e();
+  double betaZ = -p.pz() / p.e();
   bst(betaX, betaY, betaZ);
 }
 
@@ -687,11 +687,11 @@ void RotBstMatrix::bst(const Vec4& p1, const Vec4& p2) {
 
 //--------------------------------------------------------------------------
 
-// Boost and rotation that transforms from p1 and p2 
+// Boost and rotation that transforms from p1 and p2
 // to their rest frame with p1 along +z axis.
 
 void RotBstMatrix::toCMframe(const Vec4& p1, const Vec4& p2) {
-  Vec4 pSum = p1 + p2; 
+  Vec4 pSum = p1 + p2;
   Vec4 dir  = p1;
   dir.bstback(pSum);
   double theta = dir.theta();
@@ -723,13 +723,13 @@ void RotBstMatrix::fromCMframe(const Vec4& p1, const Vec4& p2) {
 
 void RotBstMatrix::rotbst(const RotBstMatrix& Mrb) {
   double Mtmp[4][4];
-  for (int i = 0; i < 4; ++i) 
-  for (int j = 0; j < 4; ++j) 
-    Mtmp[i][j] = M[i][j]; 
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    Mtmp[i][j] = M[i][j];
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
     M[i][j] = Mrb.M[i][0] * Mtmp[0][j] + Mrb.M[i][1] * Mtmp[1][j]
-            + Mrb.M[i][2] * Mtmp[2][j] + Mrb.M[i][3] * Mtmp[3][j]; 
+            + Mrb.M[i][2] * Mtmp[2][j] + Mrb.M[i][3] * Mtmp[3][j];
 }
 
 //--------------------------------------------------------------------------
@@ -738,13 +738,13 @@ void RotBstMatrix::rotbst(const RotBstMatrix& Mrb) {
 
 void RotBstMatrix::invert() {
   double Mtmp[4][4];
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
-    Mtmp[i][j] = M[i][j]; 
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
-    M[i][j] = ( (i == 0 && j > 0) || (i > 0 && j == 0) ) 
-      ? - Mtmp[j][i] : Mtmp[j][i]; 
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    Mtmp[i][j] = M[i][j];
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    M[i][j] = ( (i == 0 && j > 0) || (i > 0 && j == 0) )
+      ? - Mtmp[j][i] : Mtmp[j][i];
 }
 
 //--------------------------------------------------------------------------
@@ -752,10 +752,10 @@ void RotBstMatrix::invert() {
 // Reset to diagonal matrix.
 
 void RotBstMatrix::reset() {
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
-    M[i][j] = (i==j) ? 1. : 0.; 
-} 
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    M[i][j] = (i==j) ? 1. : 0.;
+}
 
 //--------------------------------------------------------------------------
 
@@ -763,28 +763,28 @@ void RotBstMatrix::reset() {
 
 double RotBstMatrix::deviation() const {
   double devSum = 0.;
-  for (int i = 0; i < 4; ++i)  
-  for (int j = 0; j < 4; ++j) 
-    devSum += (i==j) ? abs(M[i][j] - 1.) : abs(M[i][j]); 
+  for (int i = 0; i < 4; ++i)
+  for (int j = 0; j < 4; ++j)
+    devSum += (i==j) ? abs(M[i][j] - 1.) : abs(M[i][j]);
   return devSum;
-} 
+}
 
 //--------------------------------------------------------------------------
 
 // Print a rotation and boost matrix: operator overloading with friend.
 
 ostream& operator<<(ostream& os, const RotBstMatrix& M) {
-  os << fixed << setprecision(5) << "    Rotation/boost matrix: \n"; 
-  for (int i = 0; i <4; ++i) 
-    os << setw(10) << M.M[i][0] << setw(10) << M.M[i][1] 
-       << setw(10) << M.M[i][2] << setw(10) << M.M[i][3] << "\n"; 
-  return os; 
+  os << fixed << setprecision(5) << "    Rotation/boost matrix: \n";
+  for (int i = 0; i <4; ++i)
+    os << setw(10) << M.M[i][0] << setw(10) << M.M[i][1]
+       << setw(10) << M.M[i][2] << setw(10) << M.M[i][3] << "\n";
+  return os;
 }
 
 //==========================================================================
 
 // Hist class.
-// This class handles a single histogram at a time 
+// This class handles a single histogram at a time
 // (or a vector of histograms).
 
 //--------------------------------------------------------------------------
@@ -811,22 +811,22 @@ const double Hist::LARGE     = 1e20;
 // When minbin/maxbin < SMALLFRAC the y scale goes down to zero.
 const double Hist::SMALLFRAC = 0.1;
 
-// Constants for printout: fixed steps on y scale; filling characters. 
-const double DYAC[] = {0.04, 0.05, 0.06, 0.08, 0.10, 
+// Constants for printout: fixed steps on y scale; filling characters.
+const double DYAC[] = {0.04, 0.05, 0.06, 0.08, 0.10,
   0.12, 0.15, 0.20, 0.25, 0.30};
-const char NUMBER[] = {'0', '1', '2', '3', '4', '5', 
+const char NUMBER[] = {'0', '1', '2', '3', '4', '5',
   '6', '7', '8', '9', 'X' };
 
 //--------------------------------------------------------------------------
 
 // Book a histogram.
 
-void Hist::book(string titleIn, int nBinIn, double xMinIn, 
-  double xMaxIn) {  
+void Hist::book(string titleIn, int nBinIn, double xMinIn,
+  double xMaxIn) {
 
   title = titleIn;
-  nBin  = nBinIn; 
-  if (nBinIn < 1) nBin = 1; 
+  nBin  = nBinIn;
+  if (nBinIn < 1) nBin = 1;
   if (nBinIn > NBINMAX) nBin = NBINMAX;
   xMin  = xMinIn;
   xMax  = xMaxIn;
@@ -846,7 +846,7 @@ void Hist::null() {
   under  = 0.;
   inside = 0.;
   over   = 0.;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] = 0.;    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] = 0.;
 
 }
 
@@ -858,8 +858,8 @@ void Hist::fill(double x, double w) {
   
   ++nFill;
   int iBin = int(floor((x - xMin)/dx));
-  if (iBin < 0)          under += w;  
-  else if (iBin >= nBin) over  += w;  
+  if (iBin < 0)          under += w;
+  else if (iBin >= nBin) over  += w;
   else                 {inside += w; res[iBin] += w; }
 
 }
@@ -897,48 +897,48 @@ ostream& operator<<(ostream& os, const Hist& h) {
   for (int iCol = 1; iCol < nCol; ++iCol) {
     if (resCol[iCol] < yMin) yMin = resCol[iCol];
     if (resCol[iCol] > yMax) yMax = resCol[iCol];
-  } 
+  }
 
   // Determine scale and step size for y axis.
-  if (yMax - yMin > Hist::NLINES * DYAC[0] * 1e-9) { 
+  if (yMax - yMin > Hist::NLINES * DYAC[0] * 1e-9) {
     if (yMin > 0. && yMin < Hist::SMALLFRAC * yMax) yMin = 0.;
     if (yMax < 0. && yMax > Hist::SMALLFRAC * yMin) yMax = 0.;
     int iPowY = int(floor( log10(yMax - yMin) ));
-    if (yMax - yMin < Hist::NLINES * DYAC[0] * pow(10.,iPowY)) 
+    if (yMax - yMin < Hist::NLINES * DYAC[0] * pow(10.,iPowY))
       iPowY = iPowY - 1;
-    if (yMax - yMin > Hist::NLINES * DYAC[9] * pow(10.,iPowY)) 
+    if (yMax - yMin > Hist::NLINES * DYAC[9] * pow(10.,iPowY))
       iPowY = iPowY + 1;
     double nLinePow = Hist::NLINES * pow(10.,iPowY);
     double delY = DYAC[0];
-    for (int idel = 0; idel < 9; ++idel) 
-      if (yMax - yMin >= nLinePow * DYAC[idel]) delY = DYAC[idel+1]; 
+    for (int idel = 0; idel < 9; ++idel)
+      if (yMax - yMin >= nLinePow * DYAC[idel]) delY = DYAC[idel+1];
     double dy = delY * pow(10.,iPowY);
 
     // Convert bin contents to integer form; fractional fill in top row.
     vector<int> row(nCol);
     vector<int> frac(nCol);
-    for (int iCol = 0; iCol < nCol ; ++iCol) { 
+    for (int iCol = 0; iCol < nCol ; ++iCol) {
       double cta = abs(resCol[iCol]) / dy;
       row[iCol] = int(cta + 0.95);
       if(resCol[iCol] < 0.) row[iCol] = - row[iCol];
       frac[iCol] = int(10. * (cta + 1.05 - floor(cta + 0.95)));
-    } 
+    }
     int rowMin = int(abs(yMin)/dy + 0.95);
     if ( yMin < 0) rowMin = - rowMin;
     int rowMax = int(abs(yMax)/dy + 0.95);
     if ( yMax < 0) rowMax = - rowMax;
 
     // Print histogram row by row.
-    os << fixed << setprecision(2); 
-    for (int iRow = rowMax; iRow >= rowMin; iRow--) if (iRow != 0) { 
-      os << "  " << setw(10) << iRow*delY << "*10^" 
+    os << fixed << setprecision(2);
+    for (int iRow = rowMax; iRow >= rowMin; iRow--) if (iRow != 0) {
+      os << "  " << setw(10) << iRow*delY << "*10^"
          << setw(2) << iPowY << "  ";
-      for (int iCol = 0; iCol < nCol ; ++iCol) { 
+      for (int iCol = 0; iCol < nCol ; ++iCol) {
         if (iRow == row[iCol])                  os << NUMBER[frac[iCol]];
         else if (iRow * (row[iCol] - iRow) > 0) os << NUMBER[10];
         else                                    os << " ";
       } os << "\n";
-    } os << "\n"; 
+    } os << "\n";
 
     // Print sign and value of bin contents
     double maxim = log10(max(yMax, -yMin));
@@ -946,12 +946,12 @@ ostream& operator<<(ostream& os, const Hist& h) {
     os << "          Contents  ";
     for (int iCol = 0; iCol < nCol ; ++iCol) {
       if (resCol[iCol] < - pow(10., iPowBin - 4)) os << "-";
-      else os << " "; 
+      else os << " ";
       row[iCol] = int(abs(resCol[iCol]) * pow(10., 3 - iPowBin) + 0.5);
     } os << "\n";
     for (int iRow = 3; iRow >= 0; iRow--) {
-      os << "            *10^" << setw(2) << iPowBin + iRow - 3 << "  "; 
-      int mask = int( pow(10., iRow) + 0.5); 
+      os << "            *10^" << setw(2) << iPowBin + iRow - 3 << "  ";
+      int mask = int( pow(10., iRow) + 0.5);
       for (int iCol = 0; iCol < nCol ; ++iCol) {
         os << NUMBER[(row[iCol] / mask) % 10];
       } os << "\n";
@@ -963,38 +963,38 @@ ostream& operator<<(ostream& os, const Hist& h) {
     os << "          Low edge  ";
     for (int iCol = 0; iCol < nCol ; ++iCol) {
       if (h.xMin + iCol * nGroup * h.dx < - pow(10., iPowExp - 3)) os << "-";
-      else os << " "; 
-      row[iCol] = int(abs(h.xMin + iCol * nGroup * h.dx) 
+      else os << " ";
+      row[iCol] = int(abs(h.xMin + iCol * nGroup * h.dx)
         * pow(10., 2 - iPowExp) + 0.5);
     } os << "\n";
     for (int iRow = 2; iRow >= 0; iRow--) {
-      os << "            *10^" << setw(2) << iPowExp + iRow - 2 << "  "; 
-      int mask = int( pow(10., iRow) + 0.5); 
-      for (int iCol = 0; iCol < nCol ; ++iCol) 
+      os << "            *10^" << setw(2) << iPowExp + iRow - 2 << "  ";
+      int mask = int( pow(10., iRow) + 0.5);
+      for (int iCol = 0; iCol < nCol ; ++iCol)
         os << NUMBER[(row[iCol] / mask) % 10];
       os << "\n";
     } os << "\n";
 
   // Print explanation if histogram cannot be shown.
-  } else os << "     Histogram not shown since lowest value" << scientific 
-       << setprecision(4) << setw(12) << yMin << " and highest value" 
-       << setw(12) << yMax << " are too close \n \n"; 
+  } else os << "     Histogram not shown since lowest value" << scientific
+       << setprecision(4) << setw(12) << yMin << " and highest value"
+       << setw(12) << yMax << " are too close \n \n";
  
   // Calculate and print statistics.
   double cSum   = 0.;
   double cxSum  = 0.;
   double cxxSum = 0.;
   for (int ix = 0; ix < h.nBin ; ++ix) {
-    double cta = abs(h.res[ix]); 
+    double cta = abs(h.res[ix]);
     double x = h.xMin + (ix + 0.5) * h.dx;
     cSum   = cSum   + cta;
     cxSum  = cxSum  + cta * x;
     cxxSum = cxxSum + cta * x * x;
   }
   double xmean = cxSum / max(cSum, Hist::TINY);
-  double rms = sqrtpos( cxxSum / max(cSum, Hist::TINY) - xmean*xmean ); 
-  os << scientific << setprecision(4) 
-     << "   Entries  =" << setw(12) << h.nFill 
+  double rms = sqrtpos( cxxSum / max(cSum, Hist::TINY) - xmean*xmean );
+  os << scientific << setprecision(4)
+     << "   Entries  =" << setw(12) << h.nFill
      << "    Mean =" << setw(12) << xmean
      << "    Underflow =" << setw(12) << h.under
      << "    Low edge  =" << setw(12) << h.xMin << "\n"
@@ -1009,13 +1009,17 @@ ostream& operator<<(ostream& os, const Hist& h) {
 
 // Print histogram contents as a table (e.g. for Gnuplot).
 
-void Hist::table(ostream& os) const {
+void Hist::table(ostream& os, bool printOverUnder, bool xMidBin) const {
 
   // Print histogram vector bin by bin, with mean x as first column.
-  os << scientific << setprecision(4); 
-  for (int ix = 0; ix < nBin; ++ix) 
-    os << setw(12) << xMin + (ix + 0.5) * dx      
-       << setw(12) << res[ix] << "\n";  
+  os << scientific << setprecision(4);
+  double xBeg = (xMidBin) ? xMin + 0.5 * dx : xMin;
+  if (printOverUnder)
+    os << setw(12) << xBeg - dx << setw(12) << under << "\n";
+  for (int ix = 0; ix < nBin; ++ix)
+    os << setw(12) << xBeg + ix * dx << setw(12) << res[ix] << "\n";
+  if (printOverUnder)
+    os << setw(12) << xBeg + nBin * dx << setw(12) << over << "\n";
    
 }
 
@@ -1023,23 +1027,34 @@ void Hist::table(ostream& os) const {
 
 // Print a table out of two histograms with same x axis  (e.g. for Gnuplot).
 
-void table(const Hist& h1, const Hist& h2, ostream& os) {
+void table(const Hist& h1, const Hist& h2, ostream& os, bool printOverUnder,
+  bool xMidBin) {
 
   // Require histogram x axes to agree.
-  if (h1.nBin != h2.nBin || abs(h1.xMin - h2.xMin) > Hist::TOLERANCE * h1.dx 
+  if (h1.nBin != h2.nBin || abs(h1.xMin - h2.xMin) > Hist::TOLERANCE * h1.dx
     || abs(h1.xMax - h2.xMax) > Hist::TOLERANCE * h1.dx) return;
 
   // Print histogram vectors bin by bin, with mean x as first column.
-  os << scientific << setprecision(4); 
-  for (int ix = 0; ix < h1.nBin; ++ix) 
-    os << setw(12) << h1.xMin + (ix + 0.5) * h1.dx      
-       << setw(12) << h1.res[ix] << setw(12) << h2.res[ix] << "\n";  
+  os << scientific << setprecision(4);
+  double xBeg = (xMidBin) ? h1.xMin + 0.5 * h1.dx : h1.xMin;
+  if (printOverUnder)
+    os << setw(12) << xBeg - h1.dx << setw(12) << h1.under 
+       << setw(12) << h2.under << "\n";
+  for (int ix = 0; ix < h1.nBin; ++ix)
+    os << setw(12) << xBeg + ix * h1.dx << setw(12) << h1.res[ix] 
+       << setw(12) << h2.res[ix] << "\n";
+  if (printOverUnder)
+    os << setw(12) << xBeg + h1.nBin * h1.dx << setw(12) << h1.over 
+       << setw(12) << h2.over << "\n";
    
 }
 
-void table(const Hist& h1, const Hist& h2, string fileName) {
+void table(const Hist& h1, const Hist& h2, string fileName,
+  bool printOverUnder, bool xMidBin) {
+  
   ofstream streamName(fileName.c_str());
-  table( h1, h2, streamName);
+  table( h1, h2, streamName, printOverUnder, xMidBin);
+
 }
 
 //--------------------------------------------------------------------------
@@ -1048,10 +1063,10 @@ void table(const Hist& h1, const Hist& h2, string fileName) {
 // Special values are bin 0 for underflow and bin nBin+1 for overflow.
 // All other bins outside proper histogram range return 0.
 
-double Hist::getBinContent(int iBin) {
+double Hist::getBinContent(int iBin) const {
 
   if (iBin > 0 && iBin <= nBin) return res[iBin - 1];
-  else if (iBin == 0)           return under; 
+  else if (iBin == 0)           return under;
   else if (iBin == nBin + 1)    return over;
   else                          return 0.;
 
@@ -1067,7 +1082,7 @@ bool Hist::sameSize(const Hist& h) const {
     abs(xMax - h.xMax) < TOLERANCE * dx) return true;
   else return false;
 
-}  
+}
 
 //--------------------------------------------------------------------------
 
@@ -1077,28 +1092,28 @@ void Hist::takeLog(bool tenLog) {
 
   // Find smallest positive bin content, and put min a bit below.
   double yMin = Hist::LARGE;
-  for (int ix = 0; ix < nBin; ++ix) 
+  for (int ix = 0; ix < nBin; ++ix)
     if (res[ix] > Hist::TINY && res[ix] < yMin ) yMin = res[ix];
   yMin *= 0.8;
   
   // Take 10-logarithm bin by bin, but ensure positivity.
-  if (tenLog) { 
-    for (int ix = 0; ix < nBin; ++ix) 
+  if (tenLog) {
+    for (int ix = 0; ix < nBin; ++ix)
       res[ix] = log10( max( yMin, res[ix]) );
-    under  =  log10( max( yMin, under) ); 
-    inside =  log10( max( yMin, inside) ); 
-    over   =  log10( max( yMin, over) ); 
+    under  =  log10( max( yMin, under) );
+    inside =  log10( max( yMin, inside) );
+    over   =  log10( max( yMin, over) );
   
   // Take natural logarithm bin by bin, but ensure positivity.
-  } else { 
-    for (int ix = 0; ix < nBin; ++ix) 
+  } else {
+    for (int ix = 0; ix < nBin; ++ix)
       res[ix] = log( max( yMin, res[ix]) );
-    under  =  log( max( yMin, under) ); 
-    inside =  log( max( yMin, inside) ); 
-    over   =  log( max( yMin, over) ); 
+    under  =  log( max( yMin, under) );
+    inside =  log( max( yMin, inside) );
+    over   =  log( max( yMin, over) );
   }
 
-}  
+}
 
 //--------------------------------------------------------------------------
 
@@ -1123,7 +1138,7 @@ Hist& Hist::operator+=(const Hist& h) {
   under  += h.under;
   inside += h.inside;
   over += h.over;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] += h.res[ix];    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] += h.res[ix];
   return *this;
 }
 
@@ -1137,7 +1152,7 @@ Hist& Hist::operator-=(const Hist& h) {
   under  -= h.under;
   inside -= h.inside;
   over -= h.over;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] -= h.res[ix];    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] -= h.res[ix];
   return *this;
 }
 
@@ -1151,7 +1166,7 @@ Hist& Hist::operator*=(const Hist& h) {
   under  *= h.under;
   inside *= h.inside;
   over *= h.over;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] *= h.res[ix];    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] *= h.res[ix];
   return *this;
 }
 
@@ -1162,11 +1177,11 @@ Hist& Hist::operator*=(const Hist& h) {
 Hist& Hist::operator/=(const Hist& h) {
   if (!sameSize(h)) return *this;
   nFill += h.nFill;
-  under  = (abs(h.under) < Hist::TINY) ? 0. : under/h.under; 
-  inside = (abs(h.inside) < Hist::TINY) ? 0. : inside/h.inside; 
-  over  = (abs(h.over) < Hist::TINY) ? 0. : over/h.over; 
-  for (int ix = 0; ix < nBin; ++ix) 
-    res[ix] = (abs(h.res[ix]) < Hist::TINY) ? 0. : res[ix]/h.res[ix];    
+  under  = (abs(h.under) < Hist::TINY) ? 0. : under/h.under;
+  inside = (abs(h.inside) < Hist::TINY) ? 0. : inside/h.inside;
+  over  = (abs(h.over) < Hist::TINY) ? 0. : over/h.over;
+  for (int ix = 0; ix < nBin; ++ix)
+    res[ix] = (abs(h.res[ix]) < Hist::TINY) ? 0. : res[ix]/h.res[ix];
   return *this;
 }
 
@@ -1178,7 +1193,7 @@ Hist& Hist::operator+=(double f) {
   under  += f;
   inside += nBin * f;
   over   += f;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] += f;    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] += f;
   return *this;
 }
 
@@ -1190,7 +1205,7 @@ Hist& Hist::operator-=(double f) {
   under  -= f;
   inside -= nBin * f;
   over   -= f;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] -= f;    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] -= f;
   return *this;
 }
 
@@ -1202,7 +1217,7 @@ Hist& Hist::operator*=(double f) {
   under  *= f;
   inside *= f;
   over   *= f;
-  for (int ix = 0; ix < nBin; ++ix) res[ix] *= f;    
+  for (int ix = 0; ix < nBin; ++ix) res[ix] *= f;
   return *this;
 }
 
@@ -1217,7 +1232,7 @@ Hist& Hist::operator/=(double f) {
     over   /= f;
     for (int ix = 0; ix < nBin; ++ix) res[ix] /= f;
   // Set empty contents when division by zero.
-  } else {    
+  } else {
     under  = 0.;
     inside = 0.;
     over   = 0.;
@@ -1240,8 +1255,8 @@ Hist operator+(const Hist& h1, const Hist& h2) {
   Hist h = h1; return h += h2;}
 
 Hist operator-(double f, const Hist& h1) {
-  Hist h   = h1; 
-  h.under  = f - h1.under; 
+  Hist h   = h1;
+  h.under  = f - h1.under;
   h.inside = h1.nBin * f - h1.inside;
   h.over   = f - h1.over;
   for (int ix = 0; ix < h1.nBin; ++ix) h.res[ix] = f - h1.res[ix];
@@ -1263,12 +1278,12 @@ Hist operator*(const Hist& h1, const Hist& h2) {
   Hist h = h1; return h *= h2;}
 
 Hist operator/(double f, const Hist& h1) {
-  Hist h = h1; 
-  h.under  = (abs(h1.under)  < Hist::TINY) ? 0. :  f/h1.under; 
-  h.inside = (abs(h1.inside) < Hist::TINY) ? 0. :  f/h1.inside; 
-  h.over   = (abs(h1.over)   < Hist::TINY) ? 0. :  f/h1.over; 
-  for (int ix = 0; ix < h1.nBin; ++ix) 
-    h.res[ix] = (abs(h1.res[ix]) < Hist::TINY) ? 0. : f/h1.res[ix];  
+  Hist h = h1;
+  h.under  = (abs(h1.under)  < Hist::TINY) ? 0. :  f/h1.under;
+  h.inside = (abs(h1.inside) < Hist::TINY) ? 0. :  f/h1.inside;
+  h.over   = (abs(h1.over)   < Hist::TINY) ? 0. :  f/h1.over;
+  for (int ix = 0; ix < h1.nBin; ++ix)
+    h.res[ix] = (abs(h1.res[ix]) < Hist::TINY) ? 0. : f/h1.res[ix];
   return h;
 }
 
